package com.chemaxon.checkers.example;

import java.util.ArrayList;

import chemaxon.checkers.ExternalStructureChecker;
import chemaxon.checkers.StructureChecker;
import chemaxon.checkers.result.DefaultExternalStructureCheckerResult;
import chemaxon.checkers.result.StructureCheckerResult;
import chemaxon.struc.MolAtom;
import chemaxon.struc.MolBond;
import chemaxon.struc.Molecule;

/**
 * This class demonstrates how easy it is to implement a new {@link StructureChecker} to check
 * properties of {@link Molecule} instances and sign it by an error. This class may also be
 * called something like "MassBiggerThan500Checker" but here the name plays only demonstration
 * role.
 */

/*
 * For a developer who'd like to extend the list of the existing checker tools, the best choice
 * is to extend from ExternalStructureChecker class. It is a descendant of 
 * AbstractSturctureChecker, so it already implements all GUI property based functionalities
 * (such as name handling, error message handling, icon handling etc.) and automatically
 * sets the error type of the checker to EXTERNAL which signs that this checker isn't part
 * of the ChemAxon built-in checker list and thus the runner framework will know that this
 * checker's result has to be handled separated. And of course with this super class the
 * developer has to implement only the checker mechanism for the problem. 
 * 
 * WARNING! Of course any developer can implement a checker which will have the same error 
 * type as one of the built-in checkers but in this case there can be ambiguous issues with
 * the running framework and unexpected errors could happen. So in this case the proper 
 * work of the checker system can not be guaranteed.
 */
public class MyFirstStructureChecker extends ExternalStructureChecker {
	
	/**
	 * This {@link String} property will be the error code returned in the checker result
	 * which makes the possibility for the runner framework to identify the error and find
	 * the related fixers.
	 */
	private final String errorCode = "MyFirstErrorCode";

	/* (non-Javadoc)
	 * @see chemaxon.checkers.AbstractStructureChecker#check1(chemaxon.struc.Molecule)
	 */
	@Override
	protected StructureCheckerResult check1(Molecule molecule) {
		/*
		 * The mass of the molecule is to be checked. If it is greater than 500 Da an error will be
		 * returned otherwise null which signs that there is no such error in this molecule
		 * object. It is obvious that this is not a very useful checking mechanism but for tutorial
		 * purposes it is enough because here the target is to demonstrate the framework, not to
		 * implement any sophisticated issue. 
		 */
		return molecule.getMass()>500
				/*
				 * This result signs an error with the errorCode property a List of MolAtoms
				 * and a List of MolBonds which could contain the related components of the error
				 * and a few additional String properties which serves GUI presentation purposes
				 */
				? new DefaultExternalStructureCheckerResult(this, new ArrayList<MolAtom>(),
						new ArrayList<MolBond>(), molecule, "Molecule mass is to high", "My first checker"
						, "My first checker", "Some useful help text about the problem", 
						errorCode, null)
				: null;
	}

}
