
package com.chemaxon.checkers.example;

import chemaxon.checkers.StructureCheck;
import chemaxon.checkers.StructureCheckerErrorType;
import chemaxon.checkers.result.StructureCheckerResult;
import chemaxon.fixers.AbstractStructureFixer;
import chemaxon.fixers.Fixes;
import chemaxon.fixers.StructureFixer;
import chemaxon.struc.MolAtom;
import chemaxon.struc.Molecule;

/**
 * This class demonstrates how easy it is to implement a new {@link StructureFixer} for an existing 
 * built-in {@link StructureCheck} class' error. This class could be also called something
 * like "AddCrabonForStructureFixe" but here the name plays only a demonstration role.
 */

/*
 * Usually AbstractStructureFixer is the best choice as a super class of a new fixer
 * implementation. Because this abstract parent contains all the code to handle name and
 * description, developers have to implementing the fixer logic only and nothing
 * more.
 [3:52:04 PM] Szab Attila: "Mivel ez az abstract os tartalmazza az osszes
  szuksewges kodot a nev es a description kezelesere a programozonak csak a fixer logica implementalasaval kell tordnie"
 */
/*
 * This annotation means that this fixer could fix the errors signed by EMPTY error type
 * which is assigned to the EmptyStructureChecker class by default. So with this annotation
 * a developer can sign that this StructureFixer instance was created for fixing the empty structure
 * problem.
 */
@Fixes({StructureCheckerErrorType.EMPTY})
public class MyFirstStructureFixer extends AbstractStructureFixer {

	/* (non-Javadoc)
	 * @see chemaxon.fixers.StructureFixer#fix(chemaxon.checkers.result.StructureCheckerResult)
	 */
	@Override
	public boolean fix(StructureCheckerResult result) {
		/*
		 * We could nearly do anything with the problematic structure because the result
		 * contains all relevant information about the problem. At first, it contains a 
		 * reference to the problematic Molecule object and also a List of MolAtom and a
		 * List of MolBond. These lists contain the problematic bonds and atoms in the molecule
		 * so the developer can easily modify or delete them if it is needed for fixing the
		 * problem. See the API doc for additional information about
		 * StructureCheckerResult instances.
		 */
		
		//We get the reference for the molecule.
		Molecule mol = result.getMolecule();
		/*
		 * Add a carbon atom to have a non empty structure, thus empty structure checker no
		 * longer will sign error in this molecule structure.
		 */
		mol.add(new MolAtom(6));
		//The return value signs that the fix was complete.
		return true;
	}

}
